@@ -5,6 +5,11 @@ setGeneric("nTips", function(x) {
     standardGeneric("nTips")
 })
 
+## depthTips
+setGeneric("depthTips", function(x) {
+  standardGeneric("depthTips")
+})
+
 ## nNodes
 setGeneric("nNodes", function(x) {
     standardGeneric("nNodes")
@@ -21,6 +26,11 @@ setGeneric("nodeId", function(x, type=c("all", "tip", "internal",
     standardGeneric("nodeId")
 })
 
+## nodeDepth
+setGeneric("nodeDepth", function(x, node) {
+  standardGeneric("nodeDepth")
+})
+
 ## nEdges
 setGeneric("nEdges", function(x) {
     standardGeneric("nEdges")
@@ -148,6 +158,12 @@ setGeneric("tail")
 ## summary
 setGeneric("summary")
 
+## isUltrametric
+setGeneric("isUltrametric", function(x, tol=.Machine$double.eps^.5) {
+  standardGeneric("isUltrametric")
+})
+
+
 ### ----------- phylo4d methods -----------
 
 ## tdata
