@@ -22,7 +22,7 @@
 #include <cassert>
 using std::string;
 using std::vector;
-using std::cout;
+//using std::cout;
 using std::endl;
 
 /**===========================================================================
